pub struct ModelQualityAppSpecification {
pub container_arguments: Option<Vec<String>>,
pub container_entrypoint: Option<Vec<String>>,
pub environment: Option<HashMap<String, String>>,
pub image_uri: String,
pub post_analytics_processor_source_uri: Option<String>,
pub problem_type: Option<String>,
pub record_preprocessor_source_uri: Option<String>,
}Expand description
Container image configuration object for the monitoring job.
Fields
container_arguments: Option<Vec<String>>An array of arguments for the container used to run the monitoring job.
container_entrypoint: Option<Vec<String>>Specifies the entrypoint for a container that the monitoring job runs.
environment: Option<HashMap<String, String>>Sets the environment variables in the container that the monitoring job runs.
image_uri: StringThe address of the container image that the monitoring job runs.
post_analytics_processor_source_uri: Option<String>An Amazon S3 URI to a script that is called after analysis has been performed. Applicable only for the built-in (first party) containers.
problem_type: Option<String>The machine learning problem type of the model that the monitoring job monitors.
record_preprocessor_source_uri: Option<String>An Amazon S3 URI to a script that is called per row prior to running analysis. It can base64 decode the payload and convert it into a flatted json so that the built-in container can use the converted data. Applicable only for the built-in (first party) containers.